z80_unpacker: optimisation: -3B and ~-10T in decode_bit = 174B

unpack zx48.rom is now ~22.6s (from 23.0s)
(performance version is now 199 bytes, zx48.rom unpack 19.4s -> 19.0s)
This commit is contained in:
Peter Helcmanovsky (Ped) committed 2022-09-18 22:54:10 +02:00
1 parent b13fa05413
commit d4bce4bf7c
2 files changed
+15 -16

No files matched your search

Binary file not shown.